Working with Spec Files
=======================

.. note::

   Work in Progress


Shared Specs
************

:ref:`example_spec_files:common.yaml`
  Top level spec attributes common to all tools.


:ref:`example_spec_files:teams.yaml`
  these are used as attributes in other spec objects:

  - accounts
  - users
  - local_users



``awsorgs``
***********

:ref:`example_spec_files:organizational_units.yaml`

:ref:`example_spec_files:service_control_policies.yaml`



``awsaccounts``
***************

:ref:`example_spec_files:accounts.yaml`



``awsauth``
***********

:ref:`example_spec_files:users.yaml`

:ref:`example_spec_files:groups.yaml`

:ref:`example_spec_files:delegations.yaml`

:ref:`example_spec_files:policy_sets.yaml`

:ref:`example_spec_files:custom_policies.yaml`

:ref:`example_spec_files:local_users.yaml`



